package sample.datamodel
{
	import sample.datamodel.samplecairngorm.SamplecairngormDataModel;
	/**
	 * View層のデータバインディングのためのデータの器であるDataModelクラスです。
	 */
	[Bindable]
	public class ApplicationDataModel
	{
		/**
		 * デフォルトコンストラクタです
		 * ただし、このコンストラクタを利用しての外部からの
		 * インスタンス化は認めてはいけません。
		 * 「static」で宣言されているgetInstanceメソッドの中でのみ、
		 * このコンストラクタを呼ぶようにします。
		 */
		public function ApplicationDataModel()
		{
			_sampleModel = new SamplecairngormDataModel();
		}
		// ここでは「static」な領域に自分のインスタンスを持つようにしています。
		// Flexでは基本的にAというMXMLとBというMXMLとの値のやりとりは不可能に近いです。
		// これを有効にするために「静的」な領域にデータの器であるDataModelをもつことにより、
		// AとBとのやりとりを可能にしています。
		private static var _model:ApplicationDataModel;
		/**
		 * 「static」な領域にある自分のインスタンスを取得します。
		 * インスタンスがない場合はインスタンス化して、そのインスタンスを返却します。
		 * @return ApplicationDataModel データバインディングモデル
		 */
		public static function getInstance():ApplicationDataModel
		{
			if( _model == null )
			{
				_model = new ApplicationDataModel();
			}
			return _model;
		}
		
		// 画面固有のデータバインディングのためのDataModelクラスを定義しています。
		// View層に配置されるMXMLファイルの数に応じて、このDataModelを増やしていくほうが
		// わかりやすいと思われます。
		private var _sampleModel:SamplecairngormDataModel;
		public function get sampleModel():SamplecairngormDataModel { return _sampleModel; }
		public function set sampleModel(model:SamplecairngormDataModel):void { _sampleModel = model; }
	}
}